==> common-2.0.0-sources.jar: cn/gtmap/gtc/resource/domain/resource/metadata/ApplyRefHis.java <==
package cn.gtmap.gtc.resource.domain.resource.metadata;

import cn.gtmap.gtc.resource.domain.BaseEntity;

import javax.persistence.Entity;
import javax.persistence.Table;
import java.util.Date;

/**
 * 1 * @Author: zgl
 * 2 * @Date: 2020/6/11 14:09
 * 3
 */
@Entity
@Table(name = "gt_apply_ref_his")
public class ApplyRefHis extends BaseEntity {

    //申请任务id
    private String taskId;

    //申请理由
    private String applyReason;

    //审批意见
    private String approvalOption;

    //申请日期
    private Date applyDate;

    //审批日期
    private Date approvalDate;

    //申请人
    private String applicant;

    //审批人
    private String auditor;

    //申请人部门
    private String applyDep;

    //审批人部门
    private String approvalDep;

    //所处阶段
    private String appState;

    public String getTaskId() {
        return taskId;
    }

    public ApplyRefHis setTaskId(String taskId) {
        this.taskId = taskId;
        return this;
    }

    public String getApplyReason() {
        return applyReason;
    }

    public ApplyRefHis setApplyReason(String applyReason) {
        this.applyReason = applyReason;
        return this;
    }

    public String getApprovalOption() {
        return approvalOption;
    }

    public ApplyRefHis setApprovalOption(String approvalOption) {
        this.approvalOption = approvalOption;
        return this;
    }

    public Date getApplyDate() {
        return applyDate;
    }

    public ApplyRefHis setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
        return this;
    }

    public Date getApprovalDate() {
        return approvalDate;
    }

    public ApplyRefHis setApprovalDate(Date approvalDate) {
        this.approvalDate = approvalDate;
        return this;
    }

    public String getApplicant() {
        return applicant;
    }

    public ApplyRefHis setApplicant(String applicant) {
        this.applicant = applicant;
        return this;
    }

    public String getAuditor() {
        return auditor;
    }

    public ApplyRefHis setAuditor(String auditor) {
        this.auditor = auditor;
        return this;
    }

    public String getApplyDep() {
        return applyDep;
    }

    public ApplyRefHis setApplyDep(String applyDep) {
        this.applyDep = applyDep;
        return this;
    }

    public String getApprovalDep() {
        return approvalDep;
    }

    public ApplyRefHis setApprovalDep(String approvalDep) {
        this.approvalDep = approvalDep;
        return this;
    }


    public String getAppState() {
        return appState;
    }

    public ApplyRefHis setAppState(String appState) {
        this.appState = appState;
        return this;
    }


}

==> common-2.0.2-sources.jar: cn/gtmap/gtc/resource/domain/resource/metadata/ApplyRefHis.java <==
package cn.gtmap.gtc.resource.domain.resource.metadata;

import cn.gtmap.gtc.resource.domain.BaseEntity;

import javax.persistence.Entity;
import javax.persistence.Table;
import java.util.Date;

/**
 * 1 * @Author: zgl
 * 2 * @Date: 2020/6/11 14:09
 * 3
 */
@Entity
@Table(name = "gt_apply_ref_his")
public class ApplyRefHis extends BaseEntity {

    //申请任务id
    private String taskId;

    //申请理由
    private String applyReason;

    //审批意见
    private String approvalOption;

    //申请日期
    private Date applyDate;

    //审批日期
    private Date approvalDate;

    //申请人
    private String applicant;

    //审批人
    private String auditor;

    //申请人部门
    private String applyDep;

    //审批人部门
    private String approvalDep;

    //所处阶段
    private String appState;

    /**
     * 资源：resource、 数据汇交：dataTransfer、 数据申请：dataApply、 数据维护：dataRepair
     */
    private String type;

    /**
     * 工作流流程id
     */
    private String processInsId;

    public String getProcessInsId() {
        return processInsId;
    }

    public ApplyRefHis setProcessInsId(String processInsId) {
        this.processInsId = processInsId;
        return this;
    }

    public String getTaskId() {
        return taskId;
    }

    public ApplyRefHis setTaskId(String taskId) {
        this.taskId = taskId;
        return this;
    }

    public String getApplyReason() {
        return applyReason;
    }

    public ApplyRefHis setApplyReason(String applyReason) {
        this.applyReason = applyReason;
        return this;
    }

    public String getApprovalOption() {
        return approvalOption;
    }

    public ApplyRefHis setApprovalOption(String approvalOption) {
        this.approvalOption = approvalOption;
        return this;
    }

    public Date getApplyDate() {
        return applyDate;
    }

    public ApplyRefHis setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
        return this;
    }

    public Date getApprovalDate() {
        return approvalDate;
    }

    public ApplyRefHis setApprovalDate(Date approvalDate) {
        this.approvalDate = approvalDate;
        return this;
    }

    public String getApplicant() {
        return applicant;
    }

    public ApplyRefHis setApplicant(String applicant) {
        this.applicant = applicant;
        return this;
    }

    public String getAuditor() {
        return auditor;
    }

    public ApplyRefHis setAuditor(String auditor) {
        this.auditor = auditor;
        return this;
    }

    public String getApplyDep() {
        return applyDep;
    }

    public ApplyRefHis setApplyDep(String applyDep) {
        this.applyDep = applyDep;
        return this;
    }

    public String getApprovalDep() {
        return approvalDep;
    }

    public ApplyRefHis setApprovalDep(String approvalDep) {
        this.approvalDep = approvalDep;
        return this;
    }


    public String getAppState() {
        return appState;
    }

    public ApplyRefHis setAppState(String appState) {
        this.appState = appState;
        return this;
    }

    public String getType() {
        return type;
    }

    public ApplyRefHis setType(String type) {
        this.type = type;
        return this;
    }


}
